function [solution, it_sbest, sbest, trial_initial] = DDS(sinitial,its,to_max,fraction1,maxiter)
% =================================================================================================
% Dynamically Dimensioned Search algorithm by Bryan Tolson.  Version 1.0.2  Oct 2005
%  Small Jan 2014 edit to call get_objfunc.m file when evaluating objective
%  function.

% Coded as a MINIMZER but variable to_min converts a maximization problem 
% to a minimization problem without modifying the code below.  In other words, 
% specify to_max variable correctly and the code here does not need modification 
% for MAX or MIN objectives.
% this algorithm records all sampled solutions but only searches based on
% the best solution

% as long as the 3 global variables below are declared globally, this code
% does not require modification for specific function being optimized.
% Global variables below are initialized automatically if the program
% MainDDS_tc.m is used.  Alternatively, define them globally in workspace if the
% MainDDS_tc.m program is not used.
% =================================================================================================
global S_min; % row vector of dec variable minimums - get from main program
global S_max; % row vector of dec variable maximums - get from main program
global Discrete_flag; % determine if variable is type : continuous (0) or integer (1)

zzz=[]; % temporary flag

[~, num_dec] = size(S_min); % num_dec is the number of decision variables

solution = zeros(maxiter,3+num_dec); % column 1 =iter#, 2 =best f(x), 3 = test f(x),
   % column 4 = dec var 1 value for iter#, 5 = dec var 2 value for iter#, 6 =etc...

Lasttime=zeros(1,num_dec); % tracks iterations since last sample as a neighbour

dvn_count=0; new_value=0; dec_var=0;

%%%%%%%%%%%%%%%%%%%%%%%%%  New initialization procedure in DDS.m:
stest=[];
sbest=[];
Jtest=[];
Jbest=[];

S_range=S_max-S_min;

% =================================================================================================
% INITIAL SOLUTION
% =================================================================================================
if its>1   % its is the number of function evaluations to initialize the DDS algorithm solution
% fprintf('     Finding best starting point for trial %g using %g random samples.\n',trial_num,its);
	ileft=maxiter-its; % use this to reduce number of fevals in DDS loop
	if ileft<=0
		error('#Initialization samples >= Max # function evaluations.')
    end
    for i=1:its
        if Discrete_flag == 0   % continuous variable
            stest = S_min+S_range.*rand(1,num_dec); % uniform random samples
        else                    % discrete case
            for j = 1:num_dec
                stest(1,j) = randi([S_min(1,j), S_max(1,j)],1,1);
            end
        end
        Jtest = to_max*get_objfunc(stest); % get obj function value
        if i==1
            Jbest=Jtest;
        end
        if Jtest<=Jbest
            Jbest = Jtest;
            sbest = stest;
        end
        solution(i,1)=i;
        solution(i,2)=to_max*Jbest;
        solution(i,3)=to_max*Jtest;
        solution(i,4:3+num_dec)=stest;
    end
else  % know its=1, using a user supplied initial solution.  Calculate obj func value.
    ileft=maxiter-1; % use this to reduce number of fevals in DDS loop
    stest=sinitial;  % get from the inputs
    Jtest = get_objfunc(stest); % get obj function value
    Jbest=Jtest;
    sbest=stest;
        solution(1,1)=1;
        solution(1,2)=to_max*Jbest;
        solution(1,3)=to_max*Jtest;
        solution(1,4:3+num_dec)=stest;
end

it_sbest=its; % needed to initialize variable and avoid code failure when small # iterations
trial_initial=sbest;  % extra variable here to simplify code for tracking initial DDS solution
% =================================================================================================
%%%%%%%%%%%%%%%%%%%%%%%%%  Done initialization procedure in DDS.m

for i=1:ileft  % remaining F evals after initialization
    
    %Determine variable selected as neighbour 
    Pn=1.0-log(i)/log(ileft); % 1.0-i/ileft; % probability of being selected as neighbour
    dvn_count=0; % counter for how many decision variables vary in neighbour
    stest = sbest;  % define stest initially as current (sbest for greedy)
    randnums=rand(num_dec,1);
        for j=1:num_dec
            if randnums(j)<Pn % then j th DV selected to vary in neighbour
                dvn_count=dvn_count+1;
                new_value = neigh_value_mixed(sbest(j), S_min(j), S_max(j), fraction1, j);
                %new_value=neigh_value(sbest(j),S_min(j),S_max(j),fraction1);
                stest(j)=new_value; % change relevant dec var value in stest
            end
        end
        
    if dvn_count==0 % no DVs selected at random, so select ONE
        dec_var=ceil(num_dec*rand(1,1)); % which dec var to modify for neighbour 
        new_value = neigh_value_mixed(sbest(dec_var), S_min(dec_var), S_max(dec_var), fraction1, dec_var);
        %new_value=neigh_value(sbest(dec_var),S_min(dec_var),S_max(dec_var),fraction1);
        stest(dec_var)=new_value; % change relevant dec var value in stest
    end
    
    % get ojective function value
    Jtest = to_max*get_objfunc(stest);
    
    if Jtest<=Jbest
        Jbest = Jtest;
        sbest = stest;
        it_sbest=i+its; % iteration number best solution found
        
        %%% write new status file so that best sol'n not lost with long
        %%% runs (i.e. SWAT or other models called).  June 05 - BT
        % Comment this part of code out for fast problems!!
           filenam='status.out';
           fid = fopen(filenam,'w'); % opens file and discards current contents
           zzz=to_max*Jbest;
           fprintf(fid,'Current best objective function value of %12.5f found at iteration %6.0f\n',zzz,i+its);
           fprintf(fid,'under parameter set below: \n'); 
           fprintf(fid,' %e ',sbest);
           fclose(fid);
        %%%
    end
       
    % accumulate results
    solution(i+its,1)=i+its;
    solution(i+its,2)=to_max*Jbest;
    solution(i+its,3)=to_max*Jtest;
    solution(i+its,4:3+num_dec)=stest;

%%%%%%%% WRITE SCREEN OUTPUT - *** user uncomment if desired ***:
%        fprintf('\n\n');
%        fprintf('Jtest for iteration %g is %g\n',i+its,to_max*Jtest);
%        fprintf('Jbest for iteration %g is %g\n',i+its,to_max*Jbest);
%        fprintf('\n\n');
  
end % DDS function loop 

% fprintf('Best solution found has obj function value of %10.4f \n\n',to_max*Jbest);

% June 05.  Delete status file (if created) since run ended successfully:
if isempty(zzz)==0 % status file printed
    delete('status.out');
end
