function [] = DDS_inout(runname,obj_flag,num_trials,maxiter,user_seeds,fraction1,out_print,user_comments, ...
    ini_soln,ini_name,num_samples,filenam1,filenam2,filenam3,filenam4);

% RECORDS ALL DDS INPUTS TO AN OUTPUT FILE

global S_name;
global S_min;
global S_max;
global Discrete_flag;
global objfunc_name; % function name that returns the objective function value
global exe_name;

[nothing num_dec]=size(S_min);

numfiles=2*num_trials;

% write inputs to file:
filenam=strcat(runname,'_Input.out');
fid = fopen(filenam,'w'); % opens file and discards current contents
fprintf(fid,'This file lists all inputs for the Dynamically Dimensioned Search (DDS) Algorithm (ver 1.2) by Bryan Tolson.\n\n');

if isempty(exe_name) % obj function is m file
    name1=strcat(objfunc_name,'.m');
else % obj function is from external exe
    name1=exe_name;
end

if obj_flag==1
  fprintf(fid,'DDS algorithm used to MINIMIZE the %s function or program. \n',name1);
elseif obj_flag==-1
  fprintf(fid,'DDS algorithm used to MAXIMIZE the %s function or program. \n',name1);
end

fprintf(fid,'Date of optimization run: %s \n\n',datestr(now));
fprintf(fid,'-------------------------------------------------------------------- \n\n');

if isempty(user_comments)
    fprintf(fid,'User has no additional comments on run.\n\n');
else
    fprintf(fid,'Additional user comments on run:\n %s \n\n',user_comments);
end

fprintf(fid,'Decision variables are:\n\n');
fprintf(fid,'Name       MIN       MAX       Integer?\n');
for i=1:num_dec
    fprintf(fid,'%s  %10.4f %10.4f %10.0f \n',S_name(i,:),S_min(i),S_max(i), Discrete_flag(i,1));
end
fprintf(fid,'\n');

fprintf(fid,'DDS neighborhood size parameter:  %f \n',fraction1);

fprintf(fid,'Number of optimization trials with above parameters: %6.0f   \n',num_trials);
fprintf(fid,'Number of total objective function evaluations per trial: %6.0f   \n\n',maxiter);

if ini_soln==0
    fprintf(fid,'Program randomly generated initial solutions.\n');
        fprintf(fid,'MATLAB default random number generator (Mersenne Twister) used for this run.\n');
        fprintf(fid,'   User entered random seed 1 as: %10.0f\n',user_seeds(1));
        fprintf(fid,'   User entered random seed 2 as: %10.0f\n',user_seeds(2));
        fprintf(fid,'For each trial, %5.0f random initial solutions are evaluated & best is initial DDS solution.\n',num_samples);
        fprintf(fid,'To replicate these results use random initial solution and the same 2 random seeds.\n');
        fprintf(fid,'Use initial solution file %s and vary random seeds for more optimization trials \n',filenam1);
        fprintf(fid,'to start at the initial solutions for this run.\n\n');  
else
    fprintf(fid,'User input initial solutions from the %s file.\n',ini_name);
        fprintf(fid,'MATLAB default random number generator (Mersenne Twister) used for this run.\n');
        fprintf(fid,'   User entered random seed 1 as: %10.0f\n',user_seeds(1));
        fprintf(fid,'   User entered random seed 2 as: %10.0f\n',user_seeds(2)); 
        fprintf(fid,'To replicate these results use initial solution file and the same 2 random seeds.\n');
        fprintf(fid,'Use initial solution file %s and vary random seeds for more optimization trials \n',filenam1);
        fprintf(fid,'to start at the initial solutions for this run.\n\n');  
end

fprintf(fid,'More OUTPUT files written by program are as follows:\n');

if out_print==1
    fprintf(fid,'    %s contains initial solutions used in all trials.\n',filenam1);
    fprintf(fid,'        - Row 1 is trial 1, Row 2 is trial 2, etc.  Dec Vars 1 thru D in columns 1 thru D.\n');
    fprintf(fid,'    %s contains averaged output data across trials - Jbest and Jtest.\n',filenam2);
    fprintf(fid,'    %s contains the best decision variable (Dec Vars) values found for all trials.\n',filenam3);
    fprintf(fid,'        - Row 1 is trial 1, Row 2 is trial 2, etc.  Dec Vars 1 thru D in columns 1 thru D.\n');
    fprintf(fid,'    %s contains Jbest for all iterations across all trials.\n',filenam4);
    fprintf(fid,'        - Column 1 is Jbest from trial 1, Col 2 from trial 2 etc...\n');
else % default printing
    fprintf(fid,'    %s contains initial solutions used in all trials.\n',filenam1);
    fprintf(fid,'        - Row 1 is trial 1, Row 2 is trial 2, etc.  Dec Vars 1 thru D in columns 1 thru D.\n');
    filenamtemp=strcat(runname,'_#.out');
    fprintf(fid,'    %g files named %s store Jbest, Jtest and Dec Vars by iter# for each trial.\n',num_trials,filenamtemp);
    filenamtemp=strcat(runname,'_sbest#.out');
    fprintf(fid,'    %g files named %s store best decision variable (Dec Var) values (i.e. solutions) for each trial.\n',num_trials,filenamtemp);
    fprintf(fid,'        - Row 1 is trial 1, Row 2 is trial 2, etc.  Variables 1 thru D in columns 1 thru D.\n');
    fprintf(fid,'    %s contains averaged output data across trials - Jbest and Jtest.\n',filenam2);
    fprintf(fid,'    %s contains the best decision variable values found for all trials.\n',filenam3);
    fprintf(fid,'        - Row 1 is trial 1, Row 2 is trial 2, etc.  Dec Vars 1 thru D in columns 1 thru D.\n');
    fprintf(fid,'    %s contains Jbest for all iterations across all trials.\n',filenam4);
    fprintf(fid,'        - Column 1 is Jbest from trial 1, Col 2 from trial 2 etc...\n');
end

fprintf(fid,'\n Note that Jbest -> is the best value of the objective function found so far and \n');
fprintf(fid,'          Jtest -> is the objective function value of the test, or candidate solution. \n');

fclose(fid);
