function y = ext_function(x)

% GENERAL file used to compile and distribute DDS algorithm.
% Enables DDS users to optimize a non-Matlab funcion, e.g. a simulation model or .exe file.   
% Function to interface simulation model or external exe function with DDS optimization code
% Follow this coding framework to link DDS with any general *.exe file OR a
% batch file (*.bat) needed to compute your objective function.

% When modifying for your own simulation model optimization, make sure to
% follow the logic in STEPS 1 thru 5... but code the logic as you wish.
% For example Steps 2-4 here could be replaced by a call to a *.bat file
% which would then in turn do whatever you want (i.e. call multiple .exe
% files)

global Modeldir; % simulation model directory if used (DDS program input)

% *** CRITICAL LOGIC *** is that this communication function changes to the model
% directory AND then changes back to the original directory.  All other coding depends on this logic. 
global exe_name % Can also be a DDS input.  Or simply hardcode this.

main_dir=pwd; %%%

y=inf;          % this initial assignment of variable allows DDS to handle
                % cases where the objective function is not evaluated at
                % all.  With numeric simulation models, sometimes there can
                % be numerical problems causing a set of decision variables
                % to crash a code, not converge and hence not return an obj
                % function value.  If this happens, the obj function value 
                % assigned worst possible value and hence DDS properly thinks
                % the candidate solution is terrible.  

%%%%%%%%%%%%%%%%% STEP 1:
% switch to model directory:
cd(Modeldir); % works in Matlab prompt and compiled


%%%%%%%%%%%%%%%%% STEP 2:
% edit model input files for new decision variable values
fid = fopen('variables_in.txt','w');
for i=1:length(x)
%    fprintf(fid,'%e \n',x(i));
    fprintf(fid,'%12.5f \n',x(i));
end
fclose(fid);


%%%%%%%%%%%%%%%%% STEP 3:
% call an exe file:
dos(exe_name);
% in this example coding, it is assumed that exe_name does the following:
% 1.  Read variables_in.txt file to get new decision variable values from DDS
% 2.  Calculate new objective function value
% 3.  Write value to the file function_out.txt


%%%%%%%%%%%%%%%%% STEP 4:
% get the objective function value for DDS:
[fid, message] = fopen('function_out.txt','r');
if isempty(message) % file exists, this avoids code stopping if obj function fails
    y=fscanf(fid,'%f',[1]);
    fclose(fid);
end

%%%%%%%%%%%%%%%%% STEP 5:
% switch back to opt code dir (Matlab):
cd(main_dir)