function plot_v1(objfunc_name)  % BT

% Plotting function to automatically plot all DDS outputs saved in v1.1 of Matlab DDS algorithm.
% Written by Azadeh F., Jan 06.  Modified slightly by Bryan Tolson.

% to use this function, it can be located anywhere and run right after or
% anytime after MainDDS finishes.  Tested by BT.

fprintf('\nDDS output analysis program v1 \n')

 close all;
 clear all;
 global S_name;
 global S_max;
 global S_min;
 global objfunc_name;
 path=pwd;
 check=input('\n    Please enter "yes" if the code is executed imediatly after MainDDS: ','s');

if (strcmp(check,'Yes')| strcmp(check,'yes'))
      [objfunc_name, runname, obj_flag, num_trials, maxiter, user_seeds, fraction1, ...
        out_print, user_comments, ini_soln, ini_name, dir_path] = read_DDS_inp([]);     
      bounds; % get dec variable info    
      [num_dec nothing]=size(S_name);      
      new_path=fullfile(path,runname);
      cd(new_path);
else
    new_path=input('\n    Please input the complete path of output folder\n','s')
    [objfunc_name, runname, obj_flag, num_trials, maxiter, user_seeds, fraction1, ...
        out_print, user_comments, ini_soln, ini_name, dir_path] = read_DDS_inp(new_path);
     bounds; % get dec variable info 
%    file=strcat(objfunc_name,'.inp');
%    fid = fopen(file,'r');
%    [S_name S_min S_max]=textread(file,'%s %f %f','headerlines',1);
%    fclose(fid);
   [num_dec nothing]=size(S_name);
   cd(new_path);
end   

fprintf('	Analyzing output results ...  \n')

% *****plot Jbest average versus iteration****
b=strcat(runname,'_AVG.out');
AVG=importdata(b);
AVG_data=AVG.data;
iter=AVG_data(:,1);
best_avg=AVG_data(:,2);
test_avg=AVG_data(:,3);
figure,plot(iter,best_avg,iter,test_avg);
xlabel('iter#');
ylabel('Jbest avg and Jtest avg');
title('Average objective function values across all trials'); % BT

% *******plot all Jbests versus iter#**********
d=strcat(runname,'_trials.out');
Jbest=importdata(d);
figure,plot(iter,Jbest)
xlabel('iter#');
ylabel('Jbest');
title('Optimization traces for all trials'); % BT


% *******plot max and min of Jbest average versus iteration*************** 
if num_trials>1  % BT added this
    Max=max(Jbest,[],2);
    Min=min(Jbest,[],2);
    Med=median(Jbest,2);
        

    
    figure,plot(iter,Max,'--',iter,Min,'--',iter,Med,'-');
    title('Max , Min and Median of Jbest  versus iteration');
    xlabel('iter#');
    ylabel('Jbest'); % BT
    h = legend('Max','Min','Medaian',3);
end  % BT


%********plot normalized sbest versus DV#  *****************
g=strcat(runname,'_sbest.out');
sbest=importdata(g);                                                                                                                                                     
 dv=[1:num_dec];
 
s_min=rot90(S_min);
s_max=rot90(S_max);
for i=1:num_trials
    nbest(i,:)=(sbest(i,:)-s_min)./(s_max-s_min);
end

figure,plot(dv,nbest,'.');
set(gca,'YLim',[0 1]); 
set(gca,'XTickLabel',S_name);
ylabel('Normalized Best D.V. values (sbest)');  % BT
xlabel('Decision Variable #'); % BT
title('Normalized Decision Variable Values for all Optimization Trials'); % BT
 

% ****SCATTER plot Jtest versus normalized decision variables (stest) **********
if out_print==0  % BT - if not, data not available
    fprintf('\n     Please enter "yes" if you would like to see a scatter plot of \n'); % BT
    in=input('      function values vs. all sampled DV values (TRIAL #1 only): ','s'); % BT
    k=strcmp(in,'yes');
    k1=strcmp(in,'Yes');

    
    if (k |k1)
       if num_dec>20  % BT
         fprintf('  Sorry - too many decision variables to plot on tiled figure.\n');
         fprint('   Must do scatter plots manually - hit Enter/Return to continue.\n');
         pause
       else
         e=strcat(runname,'_1.out');
         figure;
         Jtest1=importdata(e);
         for i=1:num_dec
                Dvalue1=Jtest1.data(:,3+i);
                r=rem(num_dec,2);
                if r==0
                     b=num_dec/2;
                else 
                    b=(num_dec+1)/2;
                end;
         subplot(b,2,i);
         n1=(Dvalue1-min(Dvalue1))./(max(Dvalue1)-min(Dvalue1));
         plot(n1,Jtest1.data(:,3),'.'); 
         set(gca,'YLim',[min(Jtest1.data(:,3)) max(Jtest1.data(:,3))]);
         if i==1
             title('TRIAL #1: function values vs. all decision variable values'); % BT               
         end;                   
         end;
         xlabel('Normalized decision variable values'); % BT
         ylabel('Objective function values'); % BT
         
       end; % BT
    end;
end % BT

% BT *******  Plot CDF of all trials  *************************************
if num_trials>1  % BT added this
         file1=strcat(runname,'_trials.out');
         m1 = dlmread(file1);
         [row column]=size(m1);
         last_row_Jbest=m1(row,:);
         last_row_Jbest=last_row_Jbest(1,(1:column-1));
         if  obj_flag==1
             a='ascend';
         elseif obj_flag==-1
             a='descend';
         end
         Jbest_sort1=sort(last_row_Jbest,a);
         rank =1;
          for ( i= 1: column-2)
                y1(i)=rank/(num_trials+1);
                if Jbest_sort1(i)==Jbest_sort1(i+1)
                    y1(i+1)=y1(i);
                else
                    rank=rank+1;
                    y1(i+1)=rank/(1+num_trials);
                end
           end

          figure, plot(Jbest_sort1,y1,'--o'); grid on
           ylabel('Probability of equal or better solution');
           xlabel('Objective function');
           title(runname);
end % BT
    
cd(path);

fprintf('\n\n   Plotting Program Done.  See multiple new Figure windows.  User must Save them. \n\n');
